==> haskell-timezone-series-0.1.9-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timezone-series
version:              0.1.9
visibility:           public
id:                   timezone-series-0.1.9-K4sIPHGwkPZHR3WEEyGuF5
key:                  timezone-series-0.1.9-K4sIPHGwkPZHR3WEEyGuF5
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2018 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  56e75dfc84d6d276ea5ab5b6bda7f186
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
hidden-modules:       Data.Time.LocalTime.TimeZone.Internal.TimeVersion
import-dirs:          /usr/lib/ghc-8.10.4/site-local/timezone-series-0.1.9
library-dirs:         /usr/lib/ghc-8.10.4/site-local/timezone-series-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/timezone-series-0.1.9
hs-libraries:         HStimezone-series-0.1.9-K4sIPHGwkPZHR3WEEyGuF5
depends:              base-4.14.1.0 deepseq-1.4.4.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-timezone-series-0.1.9-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-timezone-series.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 timezone-series
version:              0.1.9
visibility:           public
id:                   timezone-series-0.1.9-B4SpoD8WeBZF5k3MGSL530
key:                  timezone-series-0.1.9-B4SpoD8WeBZF5k3MGSL530
license:              BSD-3-Clause
copyright:            Copyright (c) 2010-2018 Yitzchak Gale. All rights reserved.
maintainer:           yitz@sefer.org
author:               Yitzchak Gale
homepage:             http://projects.haskell.org/time-ng/
synopsis:             Enhanced timezone handling for Data.Time
description:
    This package endows Data.Time, from the time
    package, with several data types and functions
    for enhanced processing of timezones. For one way
    to create timezone series, see the timezone-olson
    (<http://hackage.haskell.org/package/timezone-olson>)
    and timezone-olson-th
    (<http://hackage.haskell.org/package/timezone-olson-th>)
    packages.

category:             Data
abi:                  8d52dd88b2244cdd94265ccd7b5881d9
exposed:              True
exposed-modules:      Data.Time.LocalTime.TimeZone.Series
hidden-modules:       Data.Time.LocalTime.TimeZone.Internal.TimeVersion
import-dirs:          /usr/lib/ghc-8.10.5/site-local/timezone-series-0.1.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/timezone-series-0.1.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/timezone-series-0.1.9
hs-libraries:         HStimezone-series-0.1.9-B4SpoD8WeBZF5k3MGSL530
depends:              base-4.14.2.0 deepseq-1.4.4.0 time-1.9.3
haddock-interfaces:
    /usr/share/doc/haskell-timezone-series/html/timezone-series.haddock

haddock-html:         /usr/share/doc/haskell-timezone-series/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
